from _typeshed import Incomplete

app: Incomplete

def run_command(command: str) -> str: ...
def volume_level() -> None: ...
def volume_up() -> None: ...
def volume_down() -> None: ...
def mute_toggle() -> None: ...
