from _typeshed import Incomplete

app: Incomplete

def run_command(command: str) -> str: ...
def backlight_level() -> None: ...
def backlight_up() -> None: ...
def backlight_down() -> None: ...
def do_backlight_level() -> str: ...
def do_backlight_up() -> None: ...
def do_backlight_down() -> None: ...
