class AppSettingsFonts:
    font: str
    font_regular: str
    font_light: str
    font_strong: str
    font_strong_bold: str
    font_size: int
    font_icon: str
    font_icon_size: int
    font_arrow: str
    font_arrow_size: int
    rofi_font: str
    rofi_font_size: int
    font_notification: str
    font_notification_size: int
    def __init__(self, **kwargs) -> None: ...
