from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from libqtile.widget import base

def get_layout_icon(layout_name): ...

ICONS: Incomplete

class CurrentLayoutFontIcon(base._TextBox):
    def __init__(self, width=..., **config) -> None: ...
    text: Incomplete
    def hook_response(self, layout, group) -> None: ...
    def setup_hooks(self) -> None: ...
    def remove_hooks(self) -> None: ...
    def finalize(self) -> None: ...

def build_current_layout_widget(settings: AppSettings, kwargs: dict): ...
